#ifndef SPIBUS_H
#define SPIBUS_H

#define SPIBUFFSZ 34
#define NUMSPICLIENTS 6
typedef struct spibuffers{
   char bytesBetweenCsHigh; // How many bytes should be transmitted before raising CS?
   uint8_t length; // How big is the buffer 
   char bus_init_done; // set to 1 when the buffer has been initialized by the bus
   uint8_t txClientPtr; // the first empty slot in the tx ring buffer
   uint8_t txBusPtr; // the last slot written out of the ring buffer
   uint8_t rxClientPtr; // the first empty slot in the ring buffer
   uint8_t rxBusPtr; // the slot the buffer wrote out last
   int bytesSinceCSHigh; // How many bytes we have transmitted since we last raised CS.
   uint8_t tospibus[SPIBUFFSZ]; 
   uint8_t fromspibus[SPIBUFFSZ];
} spibuffer;

int ringbuff_get_rx_count(spibuffer *pbuff); 
int ringbuff_put_next_rx_value(spibuffer *pbuff, unsigned char byte);
int ringbuff_get_next_rx_value(spibuffer *pbuff);
int ringbuff_put_next_tx_value(spibuffer *pbuff, unsigned char byte);
int ringbuff_get_next_tx_value(spibuffer *pbuff);
int ringbuff_get_tx_space(spibuffer *pbuff);
int writeable_slots(int i, int o);
int readable_slots(int i, int o);
int ringbuff_index_ptr(int q);

/**  Returns: -1 if empty
**           a number >=0 if not empty.
*/
int ringbuff_get_next_tx_value(spibuffer *pbuff)
{ 
  int i;
  int o;
  int n; // number of things in the buffer
  i=pbuff->txClientPtr;
  o=pbuff->txBusPtr;
  n=readable_slots(i, o);
  if (n>0) { // There is data to put
    // output pointer points at the last record written out
    o=ringbuff_index_ptr(o);
    pbuff->txBusPtr=o;
    return pbuff->tospibus[o];
  } 
  else return -1;
}

/**  Returns: -1 if full
**           a number >=0 if not empty.
*/
int ringbuff_put_next_rx_value(spibuffer *pbuff, unsigned char byte)
{ 
  int i;
  int o;
  int n; // number of things in the buffer
  o=pbuff->rxClientPtr;
  i=pbuff->rxBusPtr;
  n=writeable_slots(i, o);
  if (n>0) { // There is space to write to the buffer 
    // pointer points to the first empty slot 
    pbuff->fromspibus[i]=byte;
    i=ringbuff_index_ptr(i);
    pbuff->rxBusPtr=i;
    return 1;
  } 
  else return 0;
}

/*
**  Returns: -1 if empty
**           a number >=0 if not empty.
*/
int ringbuff_get_next_rx_value(spibuffer *pbuff)
{ 
  int i;
  int o;
  int n; // number of things in the buffer
  o=pbuff->rxClientPtr;
  i=pbuff->rxBusPtr;
  n=readable_slots(i, o);
  if (n>0) { // There is data to put
    // output pointer points at the last record written out
    o=ringbuff_index_ptr(o);
    pbuff->rxClientPtr=o;
    return pbuff->fromspibus[o];
  } 
  else return -1;
}

/**  Returns: -1 if empty
**           a number >=0 if not empty.
*/
int ringbuff_get_rx_count(spibuffer *pbuff)
{
  int i;
  int o;
  int n; // number of things in the buffer
  o=pbuff->rxClientPtr;
  i=pbuff->rxBusPtr;
  n=readable_slots(i, o);
  return n;
}

/**  Returns: -1 if empty
**           a number >=0 if not empty.
*/
int ringbuff_get_tx_space(spibuffer *pbuff)
{
  int i;
  int o;
  int n; // number of things in the buffer
  i=pbuff->txClientPtr;
  o=pbuff->txBusPtr;
  n=writeable_slots(i, o);
  return n;
}

/**  Returns: -1 if full
**           a number >=0 if not empty.
*/
int ringbuff_put_next_tx_value(spibuffer *pbuff, unsigned char byte)
{ 
  int i;
  int o;
  int n; // number of things in the buffer
  o=pbuff->txBusPtr;
  i=pbuff->txClientPtr;
  n=writeable_slots(i, o);
  if (n>0) { // There is space to write to the buffer 
    // pointer points to the first empty slot 
    pbuff->tospibus[i]=byte;
    i=ringbuff_index_ptr(i);
    pbuff->txClientPtr=i;
    return 1;
  } 
  else return 0;
}

#endif
int readable_slots(int i, int o)
{
  if(i<o) return i-o+SPIBUFFSZ-1;  
  else return i-o-1;
}

int writeable_slots(int i, int o)
{
  if(i<o) return o-i;  
  else return SPIBUFFSZ+o-i;
}

int ringbuff_index_ptr(int q)
{
  q++;
  if (q>=SPIBUFFSZ) q=0;
  return q;
}

